@@ -154,42 +154,10 @@ class CLASSIX:
         The indices index1 and index2 are optional parameters (int) corresponding to the 
         indices of the data points. 
         
-    
-    Toy example
-    --------
-    
-    >>> from clustering import CLASSIX
-    >>> import numpy as np
-    >>> np.random.seed(0)
-    >>> n = 10
-    >>> x, y = np.random.randn(n), np.random.randn(n)
-    >>> x, y = np.concatenate((x, 10*x - 3*y + 40)), np.concatenate((y, y+2*x + 15))
-    >>> x, y = x/x.std(), y/y.std()
-    >>> data = np.array((x,y)).T
-    >>> classix = Clustering(sorting='pca', radius=0.5, group_merging='density')
-    CLASSIX(sorting='pca', radius=0.5, group_merging='density')
-    
-    >>> classix.fit(data) # equal to 'fit_transform' but no return
-    The 20 data points were aggregated into 4 groups.
-    In total 17 comparisons were required (0.85 comparisons per data point). 
-    The 4 groups were merged into 2 clusters with the following sizes: 
-          * cluster 0 : 10
-          * cluster 1 : 10
-    Try the .explain() method to explain the clustering.
-    
-    >>> labels_ft = classix.fit_transform(data) 
-    >>> print("classix.labels_:\n", list(classix.labels_)) # classix.labels_ = classix.fit_transform(data) 
-     [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]
-    
-    >>> print("fit_transform(data):\n", list(labels_ft))
-     [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]
-    
-    >>> predict(data): 
-     [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]
     """
         
 
-    def __init__(self, radius=0.5, sorting="pca", group_merging="distance", minPts=0, norm=True, scale=1.5, post_alloc=True, n_jobs=-1, verbose=0): 
+    def __init__(self, sorting="pca", radius=0.5, minPts=0, group_merging="distance", norm=True, scale=1.5, post_alloc=True, n_jobs=-1, verbose=1): 
         # deprecated parameter (15/07/2021): noise_percent=0, distance_scale=1, eta=1, cython=True
         # eta (deprecated): float, default=1.0
         #     the value for the density-based groups merging, the groups will 
@@ -761,7 +729,6 @@ class CLASSIX:
             The data point Peter Meyer is in group 9 and the data point Anna Fields is in group 8, both of which were merged into cluster #0. 
             These two groups are connected via groups 9 -> 2 -> 8.
 
-
         plot : boolean
             Determine if visulize the explaination. Default as False.
         
@@ -781,9 +748,36 @@ class CLASSIX:
         ind_marker_size : float), optional:
             Size for visualization of data with indices index1 and index2.
     
-        sp_bbox : dict
-            Dict with properties for patches.FancyBboxPatch for starting points. Default as {'facecolor': 'tomato', 'alpha': 0.2, 'pad': 2}.
+        sp_fcolor : str
+            The color marked for starting points text box. Default as 'tomato'.
+            
+        sp_alpha : float
+            The value setting for transprency of text box for starting points. Default as 0.3.
+            
+        sp_pad : int
+            The size of text box for starting points. Default as 2.
         
+        sp_bbox : dict
+            Dict with properties for patches.FancyBboxPatch for starting points. Default as None.
+    
+        sp_fontsize : int
+            The fontsize for text marked for starting points. Default as None.
+    
+        dp_fcolor : str
+            The color marked for specified data objects text box. Default as 'tomato'.
+            
+        dp_alpha : float
+            The value setting for transprency of text box for specified data objects. Default as 0.3.
+            
+        dp_pad : int
+            The size of text box for specified data objects. Default as 2.
+            
+        dp_bbox : dict 
+            Dict with properties for patches.FancyBboxPatch for specified data objects. Default as None.
+        
+        dp_fontsize : int
+            The fontsize for text marked for specified data objects. Default as None.    
+            
         color : str
             Color for text of starting points labels in visualization. Default as "k".
         
@@ -932,14 +926,14 @@ class CLASSIX:
                     ax.scatter(x_pca[:, 0], x_pca[:, 1], marker=".", c=self.cluster_color[cluster_label1])
                     # ax.scatter(x_pca[:, 0], x_pca[:, 1], marker="*", c='pink')
                     ax.scatter(s_pca[:, 0], s_pca[:, 1], marker="p")
-                    
-                    ax.scatter(object1[0], object1[1], marker="*", s=ind_marker_size)
-                        
+                
                     if dp_fontsize is None:
                         ax.text(object1[0], object1[1], s=str(index1_name), bbox=dp_bbox, color=ind_color)
                     else:
                         ax.text(object1[0], object1[1], s=str(index1_name), fontsize=dp_fontsize, bbox=dp_bbox, color=ind_color)
-                        
+                    
+                    ax.scatter(object1[0], object1[1], marker="*", s=ind_marker_size)
+                    
                     for i in range(s_pca.shape[0]):
                         ax.add_patch(plt.Circle((s_pca[i, 0], s_pca[i, 1]), self.radius, fill=False, color=color, alpha=alpha, lw=cline_width, clip_on=False))
                         ax.set_aspect('equal', adjustable='datalim')
@@ -1183,8 +1177,6 @@ class CLASSIX:
                     #             marker="*", c='lightblue')
                     
                     ax.scatter(s_pca[:,0], s_pca[:,1], marker="p")
-                    ax.scatter(object1[0], object1[1], marker="*", s=ind_marker_size)
-                    ax.scatter(object2[0], object2[1], marker="*", s=ind_marker_size)
                     
                     if dp_fontsize is None:
                         ax.text(object1[0], object1[1], s=str(index1_name), bbox=dp_bbox, color=ind_color)
@@ -1192,7 +1184,10 @@ class CLASSIX:
                     else:
                         ax.text(object1[0], object1[1], s=str(index1_name), fontsize=dp_fontsize, bbox=dp_bbox, color=ind_color)
                         ax.text(object2[0], object2[1], s=str(index2_name), fontsize=dp_fontsize, bbox=dp_bbox, color=ind_color)
-
+                    
+                    ax.scatter(object1[0], object1[1], marker="*", s=ind_marker_size)
+                    ax.scatter(object2[0], object2[1], marker="*", s=ind_marker_size)
+                    
                     for i in range(s_pca.shape[0]):
                         if union_ind[i] in connected_paths:
                             ax.add_patch(plt.Circle((s_pca[i, 0], s_pca[i, 1]), self.radius, fill=False, color=connect_color, alpha=alpha, lw=cline_width, clip_on=False))
@@ -1567,13 +1562,13 @@ class CLASSIX:
 
             
     def __repr__(self):
-        _name = 'CLASSIX(sorting={0.sorting!r}, radius={0.radius!r}, method={0.group_merging!r})'.format(self)
+        _name = "CLASSIX(sorting={0.sorting!r}, radius={0.radius!r}, minPts={0.minPts!r}, group_merging={0.group_merging!r})".format(self)
         return _name 
 
     
     
     def __str__(self):
-        _name = 'CLASSIX(sorting={0.sorting!r}, radius={0.radius!r}, method={0.group_merging!r})'.format(self)
+        _name = 'CLASSIX(sorting={0.sorting!r}, radius={0.radius!r}, minPts={0.minPts!r}, group_merging={0.group_merging!r})'.format(self)
         return _name
     
     
@@ -1609,7 +1604,7 @@ class CLASSIX:
             raise TypeError('Expected a string type')
         if value not in ['pca', 'norm-mean', 'norm-orthant'] and value != None:
             raise ValueError(
-                "Please refer to an correct sorting way, namely 'lexi', '2-norm' and '1-norm'")
+                "Please refer to an correct sorting way, namely 'pca', 'norm-mean' and 'norm-orthant'")
         self._sorting = value
 
         
